@@ -1,26 +1,32 @@
 # -*- coding: utf-8 -*-
-# MySQL Connector/Python - MySQL driver written in Python.
-# Copyright (c) 2014, 2016, Oracle and/or its affiliates. All rights reserved.
 
-# MySQL Connector/Python is licensed under the terms of the GPLv2
-# <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
-# MySQL Connectors. There are special exceptions to the terms and
-# conditions of the GPLv2 as it is applied to this software, see the
-# FOSS License Exception
-# <http://www.mysql.com/about/legal/licensing/foss-exception.html>.
+# Copyright (c) 2014, 2018, Oracle and/or its affiliates. All rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation.
+# it under the terms of the GNU General Public License, version 2.0, as
+# published by the Free Software Foundation.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# This program is also distributed with certain software (including
+# but not limited to OpenSSL) that is licensed under separate terms,
+# as designated in a particular file or component or in included license
+# documentation.  The authors of MySQL hereby grant you an
+# additional permission to link the program and your derivative works
+# with the separately licensed software that they have included with
+# MySQL.
+#
+# Without limiting anything contained in the foregoing, this file,
+# which is part of MySQL Connector/Python, is also subject to the
+# Universal FOSS Exception, version 1.0, a copy of which can be found at
+# http://oss.oracle.com/licenses/universal-foss-exception.
+#
+# This program is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+# See the GNU General Public License, version 2.0, for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Incur., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+# along with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
 
 """Testing the C Extension MySQL C API
 """
@@ -301,10 +307,10 @@ class CExtMySQLTests(tests.MySQLConnectorTests):
         version = cmy.get_server_version()
         self.assertIsInstance(version, tuple)
         self.assertEqual(3, len(version))
-        self.assertTrue(all([isinstance(v, int) and v > 0 for v in version]))
+        self.assertTrue(all([isinstance(v, int) for v in version]))
 
-        self.assertTrue(3 < version[0] < 7)
-        self.assertTrue(0 < version[1] < 20)
+        self.assertTrue(3 < version[0] < 9)
+        self.assertTrue(0 <= version[1] < 20)
         self.assertTrue(0 < version[2] < 99)
 
     def test_thread_id(self):
@@ -455,9 +461,11 @@ class CExtMySQLTests(tests.MySQLConnectorTests):
 
         cmy1.query("DROP TABLE IF EXISTS {0}".format(table))
 
+    @unittest.skipIf(tests.MYSQL_VERSION < (8, 0, 0), "Plugin unavailable.")
     def test_change_user(self):
         connect_kwargs = self.connect_kwargs.copy()
         connect_kwargs['unix_socket'] = None
+        connect_kwargs['ssl_disabled'] = False
         cmy1 = MySQL(buffered=True)
         cmy1.connect(**connect_kwargs)
         cmy2 = MySQL(buffered=True)
@@ -477,11 +485,15 @@ class CExtMySQLTests(tests.MySQLConnectorTests):
             pass
 
         stmt = ("CREATE USER '{user}'@'{host}' IDENTIFIED WITH "
-                "mysql_native_password").format(**new_user)
+                "caching_sha2_password").format(**new_user)
         cmy1.query(stmt)
-        cmy1.query("SET old_passwords = 0")
-        res = cmy1.query("SET PASSWORD FOR '{user}'@'{host}' = "
-                   "PASSWORD('{password}')".format(**new_user))
+        if tests.MYSQL_VERSION < (8, 0, 5):
+            cmy1.query("SET old_passwords = 0")
+            res = cmy1.query("SET PASSWORD FOR '{user}'@'{host}' = "
+                             "PASSWORD('{password}')".format(**new_user))
+        else:
+            res = cmy1.query("ALTER USER '{user}'@'{host}' IDENTIFIED BY "
+                             "'{password}'".format(**new_user))
         cmy1.query("GRANT ALL ON {database}.* "
                    "TO '{user}'@'{host}'".format(**new_user))
 
@@ -530,6 +542,8 @@ class CExtMySQLTests(tests.MySQLConnectorTests):
         cmy1.set_character_set('big5')
         self.assertEqual(exp, get_variables(cmy1, variables=variables))
 
+    @unittest.skipIf(tests.MYSQL_VERSION == (5, 7, 4),
+                     "test_get_ssl_cipher not tested with MySQL version 5.7.4")
     def test_get_ssl_cipher(self):
         cmy1 = MySQL(buffered=True)
         self.assertRaises(MySQLInterfaceError, cmy1.get_ssl_cipher)
