@@ -1,25 +1,30 @@
-# MySQL Connector/Python - MySQL driver written in Python.
-# Copyright (c) 2009, 2014, Oracle and/or its affiliates. All rights reserved.
-
-# MySQL Connector/Python is licensed under the terms of the GPLv2
-# <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
-# MySQL Connectors. There are special exceptions to the terms and
-# conditions of the GPLv2 as it is applied to this software, see the
-# FOSS License Exception
-# <http://www.mysql.com/about/legal/licensing/foss-exception.html>.
+# Copyright (c) 2009, 2018, Oracle and/or its affiliates. All rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation.
+# it under the terms of the GNU General Public License, version 2.0, as
+# published by the Free Software Foundation.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# This program is also distributed with certain software (including
+# but not limited to OpenSSL) that is licensed under separate terms,
+# as designated in a particular file or component or in included license
+# documentation.  The authors of MySQL hereby grant you an
+# additional permission to link the program and your derivative works
+# with the separately licensed software that they have included with
+# MySQL.
+#
+# Without limiting anything contained in the foregoing, this file,
+# which is part of MySQL Connector/Python, is also subject to the
+# Universal FOSS Exception, version 1.0, a copy of which can be found at
+# http://oss.oracle.com/licenses/universal-foss-exception.
+#
+# This program is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+# See the GNU General Public License, version 2.0, for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+# along with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
 
 """Unittests for PEP-249
 
@@ -38,7 +43,7 @@ import mysql.connector as myconn
 class PEP249Base(tests.MySQLConnectorTests):
 
     def db_connect(self):
-        return myconn.connect(**tests.get_mysql_config())
+        return myconn.connect(use_pure=True, **tests.get_mysql_config())
 
     def get_connection_id(self, cursor):
         cid = None
@@ -69,9 +74,17 @@ class PEP249ModuleTests(PEP249Base):
         """Interface exports the connect()-function"""
         self.assertTrue(inspect.isfunction(myconn.connect),
                         "Module does not export the connect()-function")
-        cnx = myconn.connect(**tests.get_mysql_config())
+        cnx = myconn.connect(use_pure=True, **tests.get_mysql_config())
         self.assertTrue(isinstance(cnx, myconn.connection.MySQLConnection),
-                        "The connect()-method returns incorrect instance")
+                        "connect() not returning by default pure "
+                        "MySQLConnection object")
+
+        if tests.MYSQL_CAPI:
+            # By default use_pure=False
+            cnx = myconn.connect(**tests.get_mysql_config())
+            self.assertTrue(isinstance(cnx,
+                                       myconn.connection_cext.CMySQLConnection),
+                            "The connect()-method returns incorrect instance")
 
     def test_apilevel(self):
         """Interface sets the API level"""
