@@ -1,33 +1,37 @@
-# MySQL Connector/Python - MySQL driver written in Python.
-# Copyright (c) 2013, 2014, Oracle and/or its affiliates. All rights reserved.
-
-# MySQL Connector/Python is licensed under the terms of the GPLv2
-# <http://www.gnu.org/licenses/old-licenses/gpl-2.0.html>, like most
-# MySQL Connectors. There are special exceptions to the terms and
-# conditions of the GPLv2 as it is applied to this software, see the
-# FOSS License Exception
-# <http://www.mysql.com/about/legal/licensing/foss-exception.html>.
+# Copyright (c) 2013, 2017, Oracle and/or its affiliates. All rights reserved.
 #
 # This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation.
+# it under the terms of the GNU General Public License, version 2.0, as
+# published by the Free Software Foundation.
 #
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
+# This program is also distributed with certain software (including
+# but not limited to OpenSSL) that is licensed under separate terms,
+# as designated in a particular file or component or in included license
+# documentation.  The authors of MySQL hereby grant you an
+# additional permission to link the program and your derivative works
+# with the separately licensed software that they have included with
+# MySQL.
+#
+# Without limiting anything contained in the foregoing, this file,
+# which is part of MySQL Connector/Python, is also subject to the
+# Universal FOSS Exception, version 1.0, a copy of which can be found at
+# http://oss.oracle.com/licenses/universal-foss-exception.
+#
+# This program is distributed in the hope that it will be useful, but
+# WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+# See the GNU General Public License, version 2.0, for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
+# along with this program; if not, write to the Free Software Foundation, Inc.,
+# 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
 
 """Unittests code analysis
 
 Requires:
-    pylint v1.0.0 or higher
+    pylint v1.2.0 or higher
 """
 
-import sys
 import os
 import tests
 import logging
@@ -40,6 +44,7 @@ try:
     from pylint import lint
     from pylint.reporters.text import TextReporter
 except ImportError as err:
+    LOGGER.warning("pylint not available")
     _PYLINT_AVAILABLE = False
 
 _CURRENT_PATH = os.path.abspath(os.path.dirname(__file__))
@@ -55,9 +60,8 @@ class LintTests(tests.MySQLConnectorTests):
 
     def setUp(self):
         self.pylint_rc_path = PYLINTRC
-        self.dir_path = os.path.join(tests.TEST_BUILD_DIR, 'mysql', 'connector')
-        self.output_file_path = os.path.join(
-            _CURRENT_PATH, 'data', 'pylint_output.txt')
+        self.dir_path = os.path.join('lib', 'mysql', 'connector')
+        self.output_file_path = os.path.join(os.getcwd(), 'pylint_output.txt')
         self.pylint_output_file = open(self.output_file_path, "w+")
         self.failed_files = []
 
